=======================
Django Redshift Backend
=======================

This is a `Amazon Redshift`_ database backend for Django_.

.. image:: https://jazzband.co/static/img/badge.svg
    :target: https://jazzband.co/
    :alt: Jazzband

.. image:: https://img.shields.io/readthedocs/django-redshift-backend/master.svg
   :alt: Read the Docs (master)
   :target: http://django-redshift-backend.rtfd.io/

.. image:: https://img.shields.io/pypi/v/django-redshift-backend.svg
   :alt: PyPI
   :target: http://pypi.org/p/django-redshift-backend

.. image:: https://img.shields.io/pypi/pyversions/django-redshift-backend.svg
   :alt: PyPI - Python Version

.. image:: https://img.shields.io/pypi/djversions/django-redshift-backend.svg
   :alt: PyPI - Django Version

.. image:: https://img.shields.io/github/license/jazzband/django-redshift-backend.svg
   :alt: License
   :target: https://github.com/jazzband/django-redshift-backend/blob/master/LICENSE

.. image:: https://img.shields.io/travis/jazzband/django-redshift-backend/master.svg
   :alt: Travis (.org) branch
   :target: https://travis-ci.org/jazzband/django-redshift-backend

.. image:: https://img.shields.io/github/stars/jazzband/django-redshift-backend.svg?style=social&label=Stars
   :alt: GitHub stars
   :target: https://github.com/jazzband/django-redshift-backend


.. _Amazon Redshift: https://aws.amazon.com/jp/redshift/
.. _Django: https://www.djangoproject.com/

Support versions
================

This product is tested with:

* Python-2.7, 3.5, 3.6
* Django-1.11, 2.0

License
=======
Apache Software License


Contents
========

.. toctree::

   basic
   refs
   dev
   changes
   authors

